Store
=====

.. seealso::

    :doc:`Reference - Storage <./reference/papermill-storage>`

Papermill can store notebooks in a number of locations including
AWS S3, Azure data blobs, and Azure data lakes.

The modular architecture of papermill allows new data stores to be
added over time.